@@ -54,7 +54,7 @@
 
 
 /********************/
-/* Base ROM offsets */
+/* Base ROM offsets */ 
 /********************/
 
 #define ROM_BUS_INFO_BLOCK             0x400U
@@ -1277,7 +1277,7 @@ dc1394_get_camera_misc_info(raw1394handle_t handle, nodeid_t node,
     if (dc1394_query_basic_functionality(handle,node,&value) != DC1394_SUCCESS)
         return DC1394_FAILURE;
     else
-        info->mem_channel_number= (value & 0xF);
+      info->mem_channel_number= (value & 0xF);
 
     if (info->mem_channel_number>0) {
       if (dc1394_get_memory_load_ch(handle, node, &info->load_channel)
@@ -1350,27 +1350,27 @@ dc1394_get_camera_feature(raw1394handle_t handle, nodeid_t node,
       return DC1394_FAILURE;
     }
 
-    if (feature->feature_id != FEATURE_TRIGGER) 
-    {
-        feature->polarity_capable= 0;
-        feature->trigger_mode= 0;
-        feature->one_push= (value & 0x10000000UL) ? DC1394_TRUE : DC1394_FALSE;
-        feature->auto_capable=
-            (value & 0x02000000UL) ? DC1394_TRUE : DC1394_FALSE;
-        feature->manual_capable=
-            (value & 0x01000000UL) ? DC1394_TRUE : DC1394_FALSE;
-
-        feature->min= (value & 0xFFF000UL) >> 12;
-        feature->max= (value & 0xFFFUL);
-    }
-    else 
-    {
-        feature->one_push= DC1394_FALSE;
-        feature->polarity_capable=
-            (value & 0x02000000UL) ? DC1394_TRUE : DC1394_FALSE;
-        feature->trigger_mode_capable_mask= ((value >> 12) & 0x0f);
-        feature->auto_capable= DC1394_FALSE;
-        feature->manual_capable= DC1394_FALSE;
+    switch (feature->feature_id) {
+    case FEATURE_TRIGGER:
+      feature->one_push= DC1394_FALSE;
+      feature->polarity_capable=
+	(value & 0x02000000UL) ? DC1394_TRUE : DC1394_FALSE;
+      feature->trigger_mode_capable_mask= ((value >> 12) & 0x0f);
+      feature->auto_capable= DC1394_FALSE;
+      feature->manual_capable= DC1394_FALSE;
+      break;
+    default:
+      feature->polarity_capable= 0;
+      feature->trigger_mode= 0;
+      feature->one_push= (value & 0x10000000UL) ? DC1394_TRUE : DC1394_FALSE;
+      feature->auto_capable=
+	(value & 0x02000000UL) ? DC1394_TRUE : DC1394_FALSE;
+      feature->manual_capable=
+	(value & 0x01000000UL) ? DC1394_TRUE : DC1394_FALSE;
+      
+      feature->min= (value & 0xFFF000UL) >> 12;
+      feature->max= (value & 0xFFFUL);
+      break;
     }
 
     feature->absolute_capable=
@@ -1384,55 +1384,52 @@ dc1394_get_camera_feature(raw1394handle_t handle, nodeid_t node,
     updated_fid= orig_fid;
     FEATURE_TO_VALUE_OFFSET(updated_fid, offset);
 
-    if (GetCameraControlRegister(handle, node, offset, &value) < 0)
-    {
-        return DC1394_FAILURE;
+    if (GetCameraControlRegister(handle, node, offset, &value) < 0) {
+      return DC1394_FAILURE;
     }
 
-    if (orig_fid != FEATURE_TRIGGER) 
-    {
-        feature->one_push_active=
-            (value & 0x04000000UL) ? DC1394_TRUE : DC1394_FALSE;
-        feature->auto_active=
-            (value & 0x01000000UL) ? DC1394_TRUE : DC1394_FALSE;
-        feature->trigger_polarity= DC1394_FALSE;
-    }
-    else 
-    {
+    switch (feature->feature_id) {
+    case FEATURE_TRIGGER:
         feature->one_push_active= DC1394_FALSE;
         feature->trigger_polarity=
             (value & 0x01000000UL) ? DC1394_TRUE : DC1394_FALSE;
         feature->trigger_mode= (int)((value >> 14) & 0xF);
         feature->auto_active= DC1394_FALSE;
+	break;
+    default:
+        feature->one_push_active=
+            (value & 0x04000000UL) ? DC1394_TRUE : DC1394_FALSE;
+        feature->auto_active=
+            (value & 0x01000000UL) ? DC1394_TRUE : DC1394_FALSE;
+        feature->trigger_polarity= DC1394_FALSE;
+	break;
     }
 
     feature->is_on= (value & 0x02000000UL) ? DC1394_TRUE : DC1394_FALSE;
 
-    if (orig_fid == FEATURE_WHITE_BALANCE) 
-    {
-        feature->BU_value= (value & 0xFFF000UL) >> 12;
-        feature->RV_value= value & 0xFFFUL;
-    }
-    else
-    { 
-        feature->value= value & 0xFFFUL;
+    switch (orig_fid) {
+    case FEATURE_WHITE_BALANCE:
+      feature->RV_value= value & 0xFFFUL;
+      feature->BU_value= (value & 0xFFF000UL) >> 12;
+      break;
+    case FEATURE_TEMPERATURE:
+      feature->value= value & 0xFFFUL;
+      feature->target_value= value & 0xFFF000UL;
+      break;
+    default:
+      feature->value= value & 0xFFFUL;
+      break;
     }
 
-    if (orig_fid == FEATURE_TEMPERATURE)
-    {
-        feature->target_value= value & 0xFFF000UL;
+    if (feature->absolute_capable>0) {
+      dc1394_query_absolute_feature_min_max(handle, node, orig_fid,
+					    &feature->abs_min, &feature->abs_max);
+      dc1394_query_absolute_feature_value(handle, node, orig_fid,
+					  &feature->abs_value);
+      dc1394_query_absolute_control(handle, node, orig_fid,
+				    &feature->abs_control);
     }
 
-    if (feature->absolute_capable>0)
-    {
-        dc1394_query_absolute_feature_min_max(handle, node, orig_fid,
-                                      &feature->abs_min, &feature->abs_max);
-        dc1394_query_absolute_feature_value(handle, node, orig_fid,
-                                      &feature->abs_value);
-        dc1394_query_absolute_control(handle, node, orig_fid,
-                                      &feature->abs_control);
-      }
-
     return DC1394_SUCCESS;
 }
 
@@ -1684,36 +1681,7 @@ dc1394_query_basic_functionality(raw1394handle_t handle, nodeid_t node,
                                          REG_CAMERA_BASIC_FUNC_INQ, value);
     return (retval ? DC1394_FAILURE : DC1394_SUCCESS);
 }
-/*
-int
-dc1394_query_feature_control(raw1394handle_t handle, nodeid_t node,
-                             unsigned int feature, unsigned int *availability)
-{
-    quadlet_t value;
-    octlet_t offset;
 
-    if ( (feature > FEATURE_MAX) || (feature < FEATURE_MIN) )
-    {
-        return DC1394_FAILURE;
-    }
-    else if (feature < FEATURE_ZOOM)
-    {
-        offset= REG_CAMERA_FEATURE_HI_INQ;
-    }
-    else
-    {
-        offset= REG_CAMERA_FEATURE_LO_INQ;
-    }
-    if (GetCameraControlRegister(handle, node, offset, &value) < 0)
-    {
-        return DC1394_FAILURE;
-    }
-
-    *availability= IsFeatureBitSet(value, feature);
-
-    return DC1394_SUCCESS;
-}
-*/
 int
 dc1394_query_advanced_feature_offset(raw1394handle_t handle, nodeid_t node,
                                      quadlet_t *value)
@@ -1889,10 +1857,14 @@ dc1394_get_iso_channel_and_speed(raw1394handle_t handle, nodeid_t node,
                                  unsigned int *channel, unsigned int *speed)
 {
     quadlet_t value;
-    int retval= GetCameraControlRegister(handle, node, REG_CAMERA_ISO_DATA,
-                                         &value);
+    int retval;
+    
+    retval= GetCameraControlRegister(handle, node, REG_CAMERA_ISO_DATA,
+				     &value);
+    
     *channel= (unsigned int)((value >> 28) & 0xFUL);
     *speed= (unsigned int)((value >> 24) & 0x3UL);
+
     return (retval ? DC1394_FAILURE : DC1394_SUCCESS);
 }
 
@@ -1900,10 +1872,10 @@ int
 dc1394_set_iso_channel_and_speed(raw1394handle_t handle, nodeid_t node,
                                  unsigned int channel, unsigned int speed)
 {
-    int retval= SetCameraControlRegister(handle, node, REG_CAMERA_ISO_DATA,
-                                         (quadlet_t)
-                                         ( ((channel & 0xFUL) << 28) |
-                                           ((speed & 0x3UL) << 24) ));
+  int retval;
+  retval= SetCameraControlRegister(handle, node, REG_CAMERA_ISO_DATA,
+				   (quadlet_t) (((channel & 0xFUL) << 28) |
+						((speed & 0x3UL) << 24) ));
     return (retval ? DC1394_FAILURE : DC1394_SUCCESS);
 }
 
