@@ -29,7 +29,7 @@
 #include <stdio.h>
 #include <sys/time.h>
 #include <stdlib.h>
-
+ 
 /* Enumeration of data speeds */
 enum
 {
@@ -255,9 +255,6 @@ typedef struct __dc1394_cam_cap_struct
     int dma_fd;
     int port;
     struct timeval filltime;
-    int dma_extra_count;
-    unsigned char * dma_extra_buffer;
-    int do_extra_buffering;
     int drop_frames;
 } dc1394_cameracapture ;
 
@@ -274,6 +271,7 @@ typedef struct __dc1394_misc_info
   int mem_channel_number;
   int save_channel;
   int load_channel;
+
 } dc1394_miscinfo;
 
 typedef struct __dc1394_feature_info_struct 
@@ -583,6 +581,7 @@ dc1394_get_white_balance(raw1394handle_t handle, nodeid_t node,
 int
 dc1394_set_white_balance(raw1394handle_t handle, nodeid_t node,
                          unsigned int u_b_value, unsigned int v_r_value);
+
 int
 dc1394_get_hue(raw1394handle_t handle, nodeid_t node,
                unsigned int *hue);
@@ -753,7 +752,6 @@ dc1394_dma_setup_capture(raw1394handle_t handle, nodeid_t node,
                          int channel, int format, int mode,
                          int speed, int frame_rate, 
                          int num_dma_buffers,
-			 int do_extra_buffering,
                          int drop_frames,
                          const char *dma_device_file,
                          dc1394_cameracapture *camera);
@@ -1009,7 +1007,6 @@ dc1394_dma_setup_format7_capture(raw1394handle_t handle, nodeid_t node,
                                  unsigned int left, unsigned int top,
                                  unsigned int width, unsigned int height,
                                  int num_dma_buffers,
-				 int do_extra_buffering,
 				 int drop_frames,
 				 const char *dma_device_file,
                                  dc1394_cameracapture *camera);
